#
# spec file for package python-netaddr
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-netaddr
Version:        0.7.10
Release:        9.1
Url:            http://github.com/drkjam/netaddr
Summary:        Pythonic manipulation of IPv4, IPv6, CIDR, EUI and MAC network addresses
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         netaddr-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-distribute
%if 0%{?suse_version}
%py_requires
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif
%endif
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

%description
A pure Python network address representation and manipulation library.

netaddr provides a Pythonic way of working with:
    - IPv4 and IPv6 addresses and subnets (including CIDR notation);
    - MAC (Media Access Control) addresses in multiple formats;
    - IEEE EUI-64, OUI and IAB identifiers;
    - a user friendly IP glob-style format.

Included are routines for:
    - generating, sorting and summarizing IP addresses;
    - converting IP addresses and ranges between various different formats;
    - performing set based operations on groups of IP addresses and subnets;
    - arbitrary IP address range calculations and conversions;
    - querying IEEE OUI and IAB organisational information;
    - querying of IP standards related data from key IANA data sources.

%prep
%setup -q -n netaddr-%{version}
sed -i "1d" netaddr/{ip/iana,eui/ieee,tests/__init__}.py # Fix non-executable scripts
chmod -x AUTHORS CHANGELOG COPYRIGHT README LICENSE THANKS # Remove executable bit from docs

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%{python_sitelib}/*
%{_bindir}/netaddr
%doc AUTHORS CHANGELOG COPYRIGHT README LICENSE THANKS

%changelog
* Wed Sep  3 2014 ro@suse.de
- sanitize release line in specfile
* Mon Sep 10 2012 alexandre@exatati.com.br
- Update to 0.7.10:
  * A bunch of Python 3.x bug fixes. Thanks Arfrever.
  * Extended nmap support to cover full target specification.
  FIXED Issue 36 - http://github.com/drkjam/netaddr/issues/36
  - ResourceWarnings with Python >=3.2
  FIXED Issue 35 - http://github.com/drkjam/netaddr/issues/35
  - netaddr-0.7.9: Test failure with Python 3
  FIXED Issue 34 - http://github.com/drkjam/netaddr/issues/34
  - netaddr.ip.iana.SaxRecordParser.endElement() incompatible
    with Python 3.1
  FIXED Issue 33 - http://github.com/drkjam/netaddr/issues/33
  - netaddr script not installed with Python 3
  FIXED Issue 23 - http://github.com/drkjam/netaddr/issues/23
  - valid_nmap_range() does not validate nmap format case.
  FIXED Issue 22 - http://github.com/drkjam/netaddr/issues/22
  - all_matching_cidrs: documentation incorrect
* Wed Aug 29 2012 alexandre@exatati.com.br
- Update to 0.7.9:
  * Re-release to fix build removing Sphinx dependency.
- Aditional changes from 0.7.8:
  * New SAX parser for IANA data source files (contributed by
    Andrew Stromnov)
  * Fixed pickling failures with EUI, OUI and IAB classes.
  FIXED Issue 31 - http://github.com/drkjam/netaddr/issues/31
  - Exclude '39.0.0.0/8' network from reserved set. Thanks
    Andrew Stromnov
  FIXED Issue 28 - http://github.com/drkjam/netaddr/issues/28
  - Fix algorithm in ipv6_link_local to fully conform to rfc4291.
    Thanks Philipp Wollermann
  FIXED Issue 25 - http://github.com/drkjam/netaddr/issues/25
  - install_requires is too aggressive? Thanks Adam Lindsay and
    commenters.
  FIXED Issue 21 - http://github.com/drkjam/netaddr/issues/21
  - deepcopy for EUI fails. Thanks Ryan Nowakowski.
* Thu May 31 2012 alexandre@exatati.com.br
- Update to 0.7.7:
  * Comprehensive documentation update! It's only taken 4 years
    to get around to using Sphinx and I can confirm it is
  * *TOTALLY AWESOME!**
  * Various bug fixes
  * Refreshed IEEE OUI and IAB data
  * FIXED Issue 24 - http://github.com/drkjam/netaddr/issues/24
  - Fixed TypeError when comparing BaseIP instance with
    non-BaseIP objects. Thanks pvaret
  * FIXED Issue 17 - http://github.com/drkjam/netaddr/issues/17
  - For large ipv6 networks the .subnet() method fails. Thanks
    daveyss
  * FIXED Issue 20 - http://github.com/drkjam/netaddr/issues/20
  - Test failure with Python 3. Thanks Arfrever
* Tue Sep 20 2011 saschpe@suse.de
- Changed license to 'BSD-3-Clause' (SPDX style)
* Tue Sep 20 2011 saschpe@suse.de
- Fixed non-executable script rpmlint warning
- Readded dependency on python-setuptools (with python-distribute):
  You can't simply remove this, it will break RPMs update mechanism!
- Preparatory stuff belongs into the %%prep section and the %%clean
  section has a sane default
* Wed Sep 14 2011 alexandre@exatati.com.br
- Regenerate spec file with py2pack;
- Removed unneded python-setuptools BuildRequires;
- Update to 0.7.6:
  * A bug fix point release
  * Refreshed 3rd party data caches
  * Tested against Python 3.2.x and PyPy 1.6.x
  * Fixed unit tests under for Mac OSX
  Specific bug fixes addressed in this release
  - -------------------------------------------
  * FIXED Issue 15 - http://github.com/drkjam/netaddr/issues/15
  - Incorrect and invalid glob produced when last octet is not *
  * FIXED Issue 13 - http://github.com/drkjam/netaddr/issues/13
  - Added support for IPython 0.11 API changes. Thanks juliantaylor
  * FIXED Issue 11 - http://github.com/drkjam/netaddr/issues/11
  - Calling valid_glob on cidr raises ValueError. Thanks radicand
  * FIXED Issue 7 - http://github.com/drkjam/netaddr/issues/7
  - Unpickling Bug in IPSet. Thanks LuizOz and labeneator
  * FIXED Issue 2 - http://github.com/drkjam/netaddr/issues/2
  - UnboundLocalError raised in IPNetwork constructor. Thanks keesbos
  Miscellanea
  - ----------
  - Has a famous soft drink company started making it own NICs?
* Thu Mar  3 2011 saschpe@suse.de
- Spec file cleanup:
  * Added %%changelog
  * Removed empty lines
  * Added AUTHORS, CHANGELOG, COPYRIGHT, README, LICENSE and
    THANKS files (all documentation)
* Wed Oct  6 2010 alexandre@exatati.com.br
- Update to 0.7.5:
  * Python 3.x is now fully supported. The paint is still drying on this so
    please help with testing and raise bug tickets when you find any issues!
  * Moved code hosting to github. All history ported thanks to the most
    excellent tool, svn2git (http://github.com/nirvdrum/svn2git).
  * All netaddr objects now use approx. 65%% less memory due to the use of
    __slots__ in classes throughout the codebase. Thanks to Stefan Nordhausen
  and his Python guru for this suggestion!
  * Applied many optimisations and speedups throughout the codebase.
  * Fixed the behaviour of the IPNetwork constructor so it now behaves in
    a much more sensible and expected way (i.e. no longer uses inet_aton
    semantics which is just plain odd for network addresses).
  * One minor change to behaviour in this version is that the .value property
    on IPAddress and IPNetwork objects no longer support assignment using a
    string IP address. Only integer value assignments are now valid. The impact
    of this change should be minimal for the majority of users.
  * FIXED Issue 49 - http://code.google.com/p/netaddr/issues/detail?id=49
  - Incorrect IP range recognition on IPs with leading zeros
  * FIXED Issue 50 - http://code.google.com/p/netaddr/issues/detail?id=50
  - CIDR block parsing
  * FIXED Issue 52 - http://code.google.com/p/netaddr/issues/detail?id=52
  - ipv6 cidr matches incorrectly match ipv4 [sic]
  * FIXED Issue 53 - http://code.google.com/p/netaddr/issues/detail?id=53
  - Error in online documentation
  * FIXED Issue 54 - http://code.google.com/p/netaddr/issues/detail?id=54
  - IP recognition failure
  * FIXED Issue 55 - http://code.google.com/p/netaddr/issues/detail?id=55
  - Support for Python 3.x
  * FIXED Issue 56 - http://code.google.com/p/netaddr/issues/detail?id=56
  - checking IPAddress in IPNetwork
  * FIXED Issue 57 - http://code.google.com/p/netaddr/issues/detail?id=57
  - netaddr objects can't pickle
  * FIXED Issue 58 - http://code.google.com/p/netaddr/issues/detail?id=58
  - IPSet operations should accept the same arguments as IPAddress
  * FIXED Issue 59 - http://code.google.com/p/netaddr/issues/detail?id=59
  - netaddr fails to load when imported by a PowerDNS coprocess
* Wed May 12 2010 alexandre@exatati.com.br
- Initial package (0.7.4) for openSUSE.
